# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.collection_service_handlers_list_source_archetypes_response_model import (
    CollectionServiceHandlersListSourceArchetypesResponseModel,
)
from .raw_client import AsyncRawSourcesClient, RawSourcesClient


class SourcesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawSourcesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawSourcesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawSourcesClient
        """
        return self._raw_client

    def list(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> CollectionServiceHandlersListSourceArchetypesResponseModel:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CollectionServiceHandlersListSourceArchetypesResponseModel
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.sources.list()
        """
        _response = self._raw_client.list(request_options=request_options)
        return _response.data


class AsyncSourcesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawSourcesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawSourcesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawSourcesClient
        """
        return self._raw_client

    async def list(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> CollectionServiceHandlersListSourceArchetypesResponseModel:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CollectionServiceHandlersListSourceArchetypesResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.sources.list()


        asyncio.run(main())
        """
        _response = await self._raw_client.list(request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

DocumentsCreateRequestBodyOneValue = typing.Union[bool, typing.Dict[str, typing.Optional[typing.Any]], float, int, str]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    SrcHandlersWorkflowsExecuteWithConfigReqBodyInputsValue,
    WorkflowsRunRequestInputsValue,
    WorkflowsRunStreamRequestInputsValue,
    WorkflowsRunWithConfigResponse,
    WorkflowsRunWithConfigResponseZero,
)

__all__ = [
    "SrcHandlersWorkflowsExecuteWithConfigReqBodyInputsValue",
    "WorkflowsRunRequestInputsValue",
    "WorkflowsRunStreamRequestInputsValue",
    "WorkflowsRunWithConfigResponse",
    "WorkflowsRunWithConfigResponseZero",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.environment_deployment_config import EnvironmentDeploymentConfig
from ..types.src_handlers_get_workflow_environments_response import SrcHandlersGetWorkflowEnvironmentsResponse
from ..types.src_handlers_update_workflow_environment_response import SrcHandlersUpdateWorkflowEnvironmentResponse
from .raw_client import AsyncRawEnvironmentsClient, RawEnvironmentsClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class EnvironmentsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawEnvironmentsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawEnvironmentsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawEnvironmentsClient
        """
        return self._raw_client

    def list(
        self, workflow_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersGetWorkflowEnvironmentsResponse:
        """
        List all environments for a workflow in the organization

        Parameters
        ----------
        workflow_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersGetWorkflowEnvironmentsResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.environments.list(
            workflow_id="workflow_id",
        )
        """
        _response = self._raw_client.list(workflow_id, request_options=request_options)
        return _response.data

    def update(
        self,
        workflow_id: str,
        environment_id: str,
        *,
        name: str,
        description: str,
        deployments: typing.Sequence[EnvironmentDeploymentConfig],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SrcHandlersUpdateWorkflowEnvironmentResponse:
        """
        Update deployments within a workflow environment

        Parameters
        ----------
        workflow_id : str

        environment_id : str

        name : str

        description : str

        deployments : typing.Sequence[EnvironmentDeploymentConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersUpdateWorkflowEnvironmentResponse
            Successful Response

        Examples
        --------
        from scoutos import EnvironmentDeploymentConfig, Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.environments.update(
            workflow_id="workflow_id",
            environment_id="environment_id",
            name="name",
            description="description",
            deployments=[
                EnvironmentDeploymentConfig(
                    revision_lookup="latest",
                )
            ],
        )
        """
        _response = self._raw_client.update(
            workflow_id,
            environment_id,
            name=name,
            description=description,
            deployments=deployments,
            request_options=request_options,
        )
        return _response.data


class AsyncEnvironmentsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawEnvironmentsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawEnvironmentsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawEnvironmentsClient
        """
        return self._raw_client

    async def list(
        self, workflow_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersGetWorkflowEnvironmentsResponse:
        """
        List all environments for a workflow in the organization

        Parameters
        ----------
        workflow_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersGetWorkflowEnvironmentsResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.environments.list(
                workflow_id="workflow_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(workflow_id, request_options=request_options)
        return _response.data

    async def update(
        self,
        workflow_id: str,
        environment_id: str,
        *,
        name: str,
        description: str,
        deployments: typing.Sequence[EnvironmentDeploymentConfig],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SrcHandlersUpdateWorkflowEnvironmentResponse:
        """
        Update deployments within a workflow environment

        Parameters
        ----------
        workflow_id : str

        environment_id : str

        name : str

        description : str

        deployments : typing.Sequence[EnvironmentDeploymentConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersUpdateWorkflowEnvironmentResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout, EnvironmentDeploymentConfig

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.environments.update(
                workflow_id="workflow_id",
                environment_id="environment_id",
                name="name",
                description="description",
                deployments=[
                    EnvironmentDeploymentConfig(
                        revision_lookup="latest",
                    )
                ],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(
            workflow_id,
            environment_id,
            name=name,
            description=description,
            deployments=deployments,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .source_sync_website_settings_splitter import SourceSyncWebsiteSettingsSplitter
from .text_extractor import TextExtractor


class SourceSyncWebsiteSettings(UncheckedBaseModel):
    selectors: typing.Optional[typing.List[str]] = None
    exclude_selectors: typing.Optional[typing.List[str]] = None
    strip: typing.Optional[typing.List[str]] = None
    strip_urls: typing.Optional[bool] = None
    allowed_domains: typing.Optional[typing.List[str]] = None
    deny: typing.Optional[typing.List[str]] = None
    job_id: typing.Optional[str] = None
    exclude_before_lastmod_date: typing.Optional[str] = None
    splitter: typing.Optional[SourceSyncWebsiteSettingsSplitter] = None
    wait_for_load_state: typing.Optional[str] = None
    scraper: typing.Optional[str] = None
    text_extractor: typing.Optional[TextExtractor] = None
    text_extractor_config: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    max_depth: typing.Optional[int] = None
    max_page_count: typing.Optional[int] = None
    allow: typing.Optional[typing.List[str]] = None
    exclude_patterns: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    A comma-separated list of classes, ids, or tags to exclude
    """

    sitemap_urls: typing.Optional[typing.List[str]] = None
    start_urls: typing.Optional[typing.List[str]] = None
    source_archetype_id: typing.Literal["com.scoutos.website"] = "com.scoutos.website"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .documents_create_request_body import DocumentsCreateRequestBody
from .documents_create_request_body_item_value import DocumentsCreateRequestBodyItemValue
from .documents_create_request_body_one_value import DocumentsCreateRequestBodyOneValue
from .documents_create_request_body_zero_value import DocumentsCreateRequestBodyZeroValue
from .documents_update_request_value import DocumentsUpdateRequestValue

__all__ = [
    "DocumentsCreateRequestBody",
    "DocumentsCreateRequestBodyItemValue",
    "DocumentsCreateRequestBodyOneValue",
    "DocumentsCreateRequestBodyZeroValue",
    "DocumentsUpdateRequestValue",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .bare_output import BareOutput
from .baseline import Baseline
from .default_output import DefaultOutput
from .html_2_text import Html2Text

TrafilaturaOutputTrafilaturaType = typing.Union[BareOutput, Baseline, DefaultOutput, Html2Text]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..core.unchecked_base_model import construct_type
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.collection_service_handlers_delete_documents_response import (
    CollectionServiceHandlersDeleteDocumentsResponse,
)
from ..types.collection_service_handlers_get_document_response import CollectionServiceHandlersGetDocumentResponse
from ..types.collection_service_handlers_get_documents_response import CollectionServiceHandlersGetDocumentsResponse
from ..types.collection_service_handlers_update_document_response import CollectionServiceHandlersUpdateDocumentResponse
from ..types.document_response import DocumentResponse
from ..types.http_validation_error import HttpValidationError
from .types.documents_create_request_body import DocumentsCreateRequestBody
from .types.documents_update_request_value import DocumentsUpdateRequestValue

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawDocumentsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        collection_id: str,
        table_id: str,
        *,
        limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        query: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CollectionServiceHandlersGetDocumentsResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        limit : typing.Optional[int]
            Limit of records to return

        cursor : typing.Optional[str]
            Cursor to fetch next set of records

        query : typing.Optional[str]
            Search query

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CollectionServiceHandlersGetDocumentsResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents",
            method="GET",
            params={
                "limit": limit,
                "cursor": cursor,
                "query": query,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersGetDocumentsResponse,
                    construct_type(
                        type_=CollectionServiceHandlersGetDocumentsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self,
        collection_id: str,
        table_id: str,
        *,
        request: DocumentsCreateRequestBody,
        await_completion: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[DocumentResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        request : DocumentsCreateRequestBody

        await_completion : typing.Optional[bool]
            Whether to wait for document creation to complete

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[DocumentResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents",
            method="POST",
            params={
                "await_completion": await_completion,
            },
            json=convert_and_respect_annotation_metadata(
                object_=request, annotation=DocumentsCreateRequestBody, direction="write"
            ),
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DocumentResponse,
                    construct_type(
                        type_=DocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self,
        collection_id: str,
        table_id: str,
        document_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CollectionServiceHandlersGetDocumentResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        document_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CollectionServiceHandlersGetDocumentResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents/{jsonable_encoder(document_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersGetDocumentResponse,
                    construct_type(
                        type_=CollectionServiceHandlersGetDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        collection_id: str,
        document_id: str,
        table_id: str,
        *,
        request: typing.Dict[str, DocumentsUpdateRequestValue],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CollectionServiceHandlersUpdateDocumentResponse]:
        """
        Parameters
        ----------
        collection_id : str

        document_id : str

        table_id : str

        request : typing.Dict[str, DocumentsUpdateRequestValue]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CollectionServiceHandlersUpdateDocumentResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents/{jsonable_encoder(document_id)}",
            method="PUT",
            json=convert_and_respect_annotation_metadata(
                object_=request, annotation=typing.Dict[str, DocumentsUpdateRequestValue], direction="write"
            ),
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersUpdateDocumentResponse,
                    construct_type(
                        type_=CollectionServiceHandlersUpdateDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self,
        collection_id: str,
        table_id: str,
        document_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CollectionServiceHandlersDeleteDocumentsResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        document_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CollectionServiceHandlersDeleteDocumentsResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents/{jsonable_encoder(document_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersDeleteDocumentsResponse,
                    construct_type(
                        type_=CollectionServiceHandlersDeleteDocumentsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete_batch(
        self,
        collection_id: str,
        table_id: str,
        *,
        request: typing.Sequence[str],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CollectionServiceHandlersDeleteDocumentsResponse]:
        """
        Delete documents given a list of document ids.

        Parameters
        ----------
        collection_id : str

        table_id : str

        request : typing.Sequence[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CollectionServiceHandlersDeleteDocumentsResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents/delete",
            method="POST",
            json=request,
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersDeleteDocumentsResponse,
                    construct_type(
                        type_=CollectionServiceHandlersDeleteDocumentsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawDocumentsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        collection_id: str,
        table_id: str,
        *,
        limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        query: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CollectionServiceHandlersGetDocumentsResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        limit : typing.Optional[int]
            Limit of records to return

        cursor : typing.Optional[str]
            Cursor to fetch next set of records

        query : typing.Optional[str]
            Search query

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CollectionServiceHandlersGetDocumentsResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents",
            method="GET",
            params={
                "limit": limit,
                "cursor": cursor,
                "query": query,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersGetDocumentsResponse,
                    construct_type(
                        type_=CollectionServiceHandlersGetDocumentsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self,
        collection_id: str,
        table_id: str,
        *,
        request: DocumentsCreateRequestBody,
        await_completion: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[DocumentResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        request : DocumentsCreateRequestBody

        await_completion : typing.Optional[bool]
            Whether to wait for document creation to complete

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[DocumentResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents",
            method="POST",
            params={
                "await_completion": await_completion,
            },
            json=convert_and_respect_annotation_metadata(
                object_=request, annotation=DocumentsCreateRequestBody, direction="write"
            ),
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DocumentResponse,
                    construct_type(
                        type_=DocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self,
        collection_id: str,
        table_id: str,
        document_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CollectionServiceHandlersGetDocumentResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        document_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CollectionServiceHandlersGetDocumentResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents/{jsonable_encoder(document_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersGetDocumentResponse,
                    construct_type(
                        type_=CollectionServiceHandlersGetDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        collection_id: str,
        document_id: str,
        table_id: str,
        *,
        request: typing.Dict[str, DocumentsUpdateRequestValue],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CollectionServiceHandlersUpdateDocumentResponse]:
        """
        Parameters
        ----------
        collection_id : str

        document_id : str

        table_id : str

        request : typing.Dict[str, DocumentsUpdateRequestValue]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CollectionServiceHandlersUpdateDocumentResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents/{jsonable_encoder(document_id)}",
            method="PUT",
            json=convert_and_respect_annotation_metadata(
                object_=request, annotation=typing.Dict[str, DocumentsUpdateRequestValue], direction="write"
            ),
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersUpdateDocumentResponse,
                    construct_type(
                        type_=CollectionServiceHandlersUpdateDocumentResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self,
        collection_id: str,
        table_id: str,
        document_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CollectionServiceHandlersDeleteDocumentsResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        document_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CollectionServiceHandlersDeleteDocumentsResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents/{jsonable_encoder(document_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersDeleteDocumentsResponse,
                    construct_type(
                        type_=CollectionServiceHandlersDeleteDocumentsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete_batch(
        self,
        collection_id: str,
        table_id: str,
        *,
        request: typing.Sequence[str],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CollectionServiceHandlersDeleteDocumentsResponse]:
        """
        Delete documents given a list of document ids.

        Parameters
        ----------
        collection_id : str

        table_id : str

        request : typing.Sequence[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CollectionServiceHandlersDeleteDocumentsResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/documents/delete",
            method="POST",
            json=request,
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersDeleteDocumentsResponse,
                    construct_type(
                        type_=CollectionServiceHandlersDeleteDocumentsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .actor import Actor
from .actor_type import ActorType
from .api_key_identity import ApiKeyIdentity
from .bare_input import BareInput
from .bare_output import BareOutput
from .baseline import Baseline
from .block_config_item_boolean import BlockConfigItemBoolean
from .block_config_item_json import BlockConfigItemJson
from .block_config_item_llm import BlockConfigItemLlm
from .block_config_item_number import BlockConfigItemNumber
from .block_config_item_number_default_value import BlockConfigItemNumberDefaultValue
from .block_config_item_number_maximum_value import BlockConfigItemNumberMaximumValue
from .block_config_item_number_minimum_value import BlockConfigItemNumberMinimumValue
from .block_config_item_number_value import BlockConfigItemNumberValue
from .block_config_item_select import BlockConfigItemSelect
from .block_config_item_text_long import BlockConfigItemTextLong
from .block_config_item_text_long_value import BlockConfigItemTextLongValue
from .block_config_item_text_short import BlockConfigItemTextShort
from .block_input import BlockInput
from .block_input_block_config_item import BlockInputBlockConfigItem
from .block_output import BlockOutput
from .block_output_block_config_item import BlockOutputBlockConfigItem
from .block_run import BlockRun
from .block_run_completed import BlockRunCompleted
from .block_run_completed_data import BlockRunCompletedData
from .block_run_completed_environment import BlockRunCompletedEnvironment
from .block_run_failed import BlockRunFailed
from .block_run_failed_data import BlockRunFailedData
from .block_run_failed_environment import BlockRunFailedEnvironment
from .block_run_started import BlockRunStarted
from .block_run_started_data import BlockRunStartedData
from .block_run_started_environment import BlockRunStartedEnvironment
from .block_run_usage import BlockRunUsage
from .block_state_updated import BlockStateUpdated
from .block_state_updated_data import BlockStateUpdatedData
from .block_state_updated_data_update_type import BlockStateUpdatedDataUpdateType
from .block_state_updated_environment import BlockStateUpdatedEnvironment
from .check_box_column import CheckBoxColumn
from .collection import Collection
from .collection_config import CollectionConfig
from .collection_destination import CollectionDestination
from .collection_service_handlers_create_collection_response import CollectionServiceHandlersCreateCollectionResponse
from .collection_service_handlers_create_sync_response import CollectionServiceHandlersCreateSyncResponse
from .collection_service_handlers_create_table_response import CollectionServiceHandlersCreateTableResponse
from .collection_service_handlers_delete_collection_response import CollectionServiceHandlersDeleteCollectionResponse
from .collection_service_handlers_delete_documents_response import CollectionServiceHandlersDeleteDocumentsResponse
from .collection_service_handlers_delete_sync_response import CollectionServiceHandlersDeleteSyncResponse
from .collection_service_handlers_delete_table_response import CollectionServiceHandlersDeleteTableResponse
from .collection_service_handlers_get_collection_response import CollectionServiceHandlersGetCollectionResponse
from .collection_service_handlers_get_collections_response import CollectionServiceHandlersGetCollectionsResponse
from .collection_service_handlers_get_document_response import CollectionServiceHandlersGetDocumentResponse
from .collection_service_handlers_get_documents_response import CollectionServiceHandlersGetDocumentsResponse
from .collection_service_handlers_get_sync_response import CollectionServiceHandlersGetSyncResponse
from .collection_service_handlers_get_table_response import CollectionServiceHandlersGetTableResponse
from .collection_service_handlers_get_tables_response import CollectionServiceHandlersGetTablesResponse
from .collection_service_handlers_list_collection_syncs_response_model import (
    CollectionServiceHandlersListCollectionSyncsResponseModel,
)
from .collection_service_handlers_list_source_archetypes_response_model import (
    CollectionServiceHandlersListSourceArchetypesResponseModel,
)
from .collection_service_handlers_table_sync_response import CollectionServiceHandlersTableSyncResponse
from .collection_service_handlers_update_collection_response import CollectionServiceHandlersUpdateCollectionResponse
from .collection_service_handlers_update_document_response import CollectionServiceHandlersUpdateDocumentResponse
from .collection_service_handlers_update_sync_response import CollectionServiceHandlersUpdateSyncResponse
from .collection_service_handlers_update_table_response import CollectionServiceHandlersUpdateTableResponse
from .column_type import ColumnType
from .column_type_base import ColumnTypeBase
from .copilot import Copilot
from .copilot_config import CopilotConfig
from .copilot_config_code_theme import CopilotConfigCodeTheme
from .copilot_config_fab_value import CopilotConfigFabValue
from .copilot_config_mode import CopilotConfigMode
from .custom import Custom
from .data_type import DataType
from .default_input import DefaultInput
from .default_output import DefaultOutput
from .dependency import Dependency
from .dimensions import Dimensions
from .document import Document
from .document_data_value import DocumentDataValue
from .document_response import DocumentResponse
from .edge_ui import EdgeUi
from .environment import Environment
from .environment_config import EnvironmentConfig
from .environment_deployment_config import EnvironmentDeploymentConfig
from .environment_deployment_config_revision_lookup import EnvironmentDeploymentConfigRevisionLookup
from .environment_deployment_document import EnvironmentDeploymentDocument
from .event_version import EventVersion
from .favor import Favor
from .html_2_text import Html2Text
from .http import Http
from .http_validation_error import HttpValidationError
from .identity import Identity
from .identity_details import IdentityDetails
from .identity_types import IdentityTypes
from .json_column import JsonColumn
from .mapping import Mapping
from .mark_down_with_context import MarkDownWithContext
from .markdown_column import MarkdownColumn
from .markdown_splitter_config import MarkdownSplitterConfig
from .message import Message
from .message_chunk import MessageChunk
from .multi_page_crawler_settings_input import MultiPageCrawlerSettingsInput
from .multi_page_crawler_settings_input_scraper import MultiPageCrawlerSettingsInputScraper
from .multi_page_crawler_settings_input_text_extractor import MultiPageCrawlerSettingsInputTextExtractor
from .multi_page_crawler_settings_output import MultiPageCrawlerSettingsOutput
from .multi_page_crawler_settings_output_scraper import MultiPageCrawlerSettingsOutputScraper
from .multi_page_crawler_settings_output_text_extractor import MultiPageCrawlerSettingsOutputTextExtractor
from .node_ui import NodeUi
from .number_column import NumberColumn
from .number_column_default import NumberColumnDefault
from .number_column_max_value import NumberColumnMaxValue
from .number_column_min_value import NumberColumnMinValue
from .paragraph_splitter_config import ParagraphSplitterConfig
from .placeholder_input import PlaceholderInput
from .placeholder_input_type import PlaceholderInputType
from .placeholder_output import PlaceholderOutput
from .placeholder_output_type import PlaceholderOutputType
from .playwright import Playwright
from .playwright_wait_for_load_state import PlaywrightWaitForLoadState
from .position import Position
from .prompt import Prompt
from .prompt_role import PromptRole
from .readability import Readability
from .recursive_splitter_config import RecursiveSplitterConfig
from .req_body import ReqBody
from .request_body import RequestBody
from .response_model_usage import ResponseModelUsage
from .run_log import RunLog
from .run_log_pagination import RunLogPagination
from .schedule import Schedule
from .schema_response import SchemaResponse
from .select_column import SelectColumn
from .select_option_item import SelectOptionItem
from .sentence_splitter_config import SentenceSplitterConfig
from .single_page_crawler_settings_input import SinglePageCrawlerSettingsInput
from .single_page_crawler_settings_input_scraper import SinglePageCrawlerSettingsInputScraper
from .single_page_crawler_settings_input_text_extractor import SinglePageCrawlerSettingsInputTextExtractor
from .single_page_crawler_settings_output import SinglePageCrawlerSettingsOutput
from .single_page_crawler_settings_output_scraper import SinglePageCrawlerSettingsOutputScraper
from .single_page_crawler_settings_output_text_extractor import SinglePageCrawlerSettingsOutputTextExtractor
from .sitemap_crawler_settings_input import SitemapCrawlerSettingsInput
from .sitemap_crawler_settings_input_scraper import SitemapCrawlerSettingsInputScraper
from .sitemap_crawler_settings_input_text_extractor import SitemapCrawlerSettingsInputTextExtractor
from .sitemap_crawler_settings_output import SitemapCrawlerSettingsOutput
from .sitemap_crawler_settings_output_scraper import SitemapCrawlerSettingsOutputScraper
from .sitemap_crawler_settings_output_text_extractor import SitemapCrawlerSettingsOutputTextExtractor
from .source_archetype import SourceArchetype
from .source_sync_crawl_settings_input import SourceSyncCrawlSettingsInput
from .source_sync_crawl_settings_output import SourceSyncCrawlSettingsOutput
from .source_sync_notion_settings import SourceSyncNotionSettings
from .source_sync_page_crawl_settings_input import SourceSyncPageCrawlSettingsInput
from .source_sync_page_crawl_settings_output import SourceSyncPageCrawlSettingsOutput
from .source_sync_sitemap_settings_input import SourceSyncSitemapSettingsInput
from .source_sync_sitemap_settings_output import SourceSyncSitemapSettingsOutput
from .source_sync_website_settings import SourceSyncWebsiteSettings
from .source_sync_website_settings_splitter import SourceSyncWebsiteSettingsSplitter
from .src_handlers_create_copilot_response import SrcHandlersCreateCopilotResponse
from .src_handlers_create_workflow_response import SrcHandlersCreateWorkflowResponse
from .src_handlers_create_workflow_revision_response import SrcHandlersCreateWorkflowRevisionResponse
from .src_handlers_delete_copilot_response import SrcHandlersDeleteCopilotResponse
from .src_handlers_delete_workflow_response import SrcHandlersDeleteWorkflowResponse
from .src_handlers_delete_workflow_revision_response import SrcHandlersDeleteWorkflowRevisionResponse
from .src_handlers_get_copilot_response import SrcHandlersGetCopilotResponse
from .src_handlers_get_workflow_environments_response import SrcHandlersGetWorkflowEnvironmentsResponse
from .src_handlers_get_workflow_response import SrcHandlersGetWorkflowResponse
from .src_handlers_list_copilots_response import SrcHandlersListCopilotsResponse
from .src_handlers_list_workflow_revisions_response import SrcHandlersListWorkflowRevisionsResponse
from .src_handlers_list_workflows_response import SrcHandlersListWorkflowsResponse
from .src_handlers_promote_workflow_revision_response import SrcHandlersPromoteWorkflowRevisionResponse
from .src_handlers_update_copilot_response import SrcHandlersUpdateCopilotResponse
from .src_handlers_update_workflow_environment_response import SrcHandlersUpdateWorkflowEnvironmentResponse
from .src_handlers_update_workflow_response import SrcHandlersUpdateWorkflowResponse
from .sync import Sync
from .sync_config_input import SyncConfigInput
from .sync_config_input_source_settings import SyncConfigInputSourceSettings
from .sync_config_output import SyncConfigOutput
from .sync_config_output_source_settings import SyncConfigOutputSourceSettings
from .table import Table
from .table_config_output import TableConfigOutput
from .table_config_output_schema_item import TableConfigOutputSchemaItem
from .text_extractor import TextExtractor
from .text_extractor_config import TextExtractorConfig
from .text_long_column import TextLongColumn
from .text_short_column import TextShortColumn
from .trafilatura_input import TrafilaturaInput
from .trafilatura_input_trafilatura_type import TrafilaturaInputTrafilaturaType
from .trafilatura_output import TrafilaturaOutput
from .trafilatura_output_trafilatura_type import TrafilaturaOutputTrafilaturaType
from .url_column import UrlColumn
from .usage import Usage
from .user_identity import UserIdentity
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem
from .workflow import Workflow
from .workflow_config_input import WorkflowConfigInput
from .workflow_config_output import WorkflowConfigOutput
from .workflow_note_input import WorkflowNoteInput
from .workflow_note_output import WorkflowNoteOutput
from .workflow_run import WorkflowRun
from .workflow_run_completed import WorkflowRunCompleted
from .workflow_run_completed_data import WorkflowRunCompletedData
from .workflow_run_completed_environment import WorkflowRunCompletedEnvironment
from .workflow_run_failed import WorkflowRunFailed
from .workflow_run_failed_data import WorkflowRunFailedData
from .workflow_run_failed_environment import WorkflowRunFailedEnvironment
from .workflow_run_response import WorkflowRunResponse
from .workflow_run_started import WorkflowRunStarted
from .workflow_run_started_data import WorkflowRunStartedData
from .workflow_run_started_environment import WorkflowRunStartedEnvironment
from .workflow_run_state_value import WorkflowRunStateValue
from .workflow_run_stop_reason import WorkflowRunStopReason
from .workflow_run_stream_response import WorkflowRunStreamResponse

__all__ = [
    "Actor",
    "ActorType",
    "ApiKeyIdentity",
    "BareInput",
    "BareOutput",
    "Baseline",
    "BlockConfigItemBoolean",
    "BlockConfigItemJson",
    "BlockConfigItemLlm",
    "BlockConfigItemNumber",
    "BlockConfigItemNumberDefaultValue",
    "BlockConfigItemNumberMaximumValue",
    "BlockConfigItemNumberMinimumValue",
    "BlockConfigItemNumberValue",
    "BlockConfigItemSelect",
    "BlockConfigItemTextLong",
    "BlockConfigItemTextLongValue",
    "BlockConfigItemTextShort",
    "BlockInput",
    "BlockInputBlockConfigItem",
    "BlockOutput",
    "BlockOutputBlockConfigItem",
    "BlockRun",
    "BlockRunCompleted",
    "BlockRunCompletedData",
    "BlockRunCompletedEnvironment",
    "BlockRunFailed",
    "BlockRunFailedData",
    "BlockRunFailedEnvironment",
    "BlockRunStarted",
    "BlockRunStartedData",
    "BlockRunStartedEnvironment",
    "BlockRunUsage",
    "BlockStateUpdated",
    "BlockStateUpdatedData",
    "BlockStateUpdatedDataUpdateType",
    "BlockStateUpdatedEnvironment",
    "CheckBoxColumn",
    "Collection",
    "CollectionConfig",
    "CollectionDestination",
    "CollectionServiceHandlersCreateCollectionResponse",
    "CollectionServiceHandlersCreateSyncResponse",
    "CollectionServiceHandlersCreateTableResponse",
    "CollectionServiceHandlersDeleteCollectionResponse",
    "CollectionServiceHandlersDeleteDocumentsResponse",
    "CollectionServiceHandlersDeleteSyncResponse",
    "CollectionServiceHandlersDeleteTableResponse",
    "CollectionServiceHandlersGetCollectionResponse",
    "CollectionServiceHandlersGetCollectionsResponse",
    "CollectionServiceHandlersGetDocumentResponse",
    "CollectionServiceHandlersGetDocumentsResponse",
    "CollectionServiceHandlersGetSyncResponse",
    "CollectionServiceHandlersGetTableResponse",
    "CollectionServiceHandlersGetTablesResponse",
    "CollectionServiceHandlersListCollectionSyncsResponseModel",
    "CollectionServiceHandlersListSourceArchetypesResponseModel",
    "CollectionServiceHandlersTableSyncResponse",
    "CollectionServiceHandlersUpdateCollectionResponse",
    "CollectionServiceHandlersUpdateDocumentResponse",
    "CollectionServiceHandlersUpdateSyncResponse",
    "CollectionServiceHandlersUpdateTableResponse",
    "ColumnType",
    "ColumnTypeBase",
    "Copilot",
    "CopilotConfig",
    "CopilotConfigCodeTheme",
    "CopilotConfigFabValue",
    "CopilotConfigMode",
    "Custom",
    "DataType",
    "DefaultInput",
    "DefaultOutput",
    "Dependency",
    "Dimensions",
    "Document",
    "DocumentDataValue",
    "DocumentResponse",
    "EdgeUi",
    "Environment",
    "EnvironmentConfig",
    "EnvironmentDeploymentConfig",
    "EnvironmentDeploymentConfigRevisionLookup",
    "EnvironmentDeploymentDocument",
    "EventVersion",
    "Favor",
    "Html2Text",
    "Http",
    "HttpValidationError",
    "Identity",
    "IdentityDetails",
    "IdentityTypes",
    "JsonColumn",
    "Mapping",
    "MarkDownWithContext",
    "MarkdownColumn",
    "MarkdownSplitterConfig",
    "Message",
    "MessageChunk",
    "MultiPageCrawlerSettingsInput",
    "MultiPageCrawlerSettingsInputScraper",
    "MultiPageCrawlerSettingsInputTextExtractor",
    "MultiPageCrawlerSettingsOutput",
    "MultiPageCrawlerSettingsOutputScraper",
    "MultiPageCrawlerSettingsOutputTextExtractor",
    "NodeUi",
    "NumberColumn",
    "NumberColumnDefault",
    "NumberColumnMaxValue",
    "NumberColumnMinValue",
    "ParagraphSplitterConfig",
    "PlaceholderInput",
    "PlaceholderInputType",
    "PlaceholderOutput",
    "PlaceholderOutputType",
    "Playwright",
    "PlaywrightWaitForLoadState",
    "Position",
    "Prompt",
    "PromptRole",
    "Readability",
    "RecursiveSplitterConfig",
    "ReqBody",
    "RequestBody",
    "ResponseModelUsage",
    "RunLog",
    "RunLogPagination",
    "Schedule",
    "SchemaResponse",
    "SelectColumn",
    "SelectOptionItem",
    "SentenceSplitterConfig",
    "SinglePageCrawlerSettingsInput",
    "SinglePageCrawlerSettingsInputScraper",
    "SinglePageCrawlerSettingsInputTextExtractor",
    "SinglePageCrawlerSettingsOutput",
    "SinglePageCrawlerSettingsOutputScraper",
    "SinglePageCrawlerSettingsOutputTextExtractor",
    "SitemapCrawlerSettingsInput",
    "SitemapCrawlerSettingsInputScraper",
    "SitemapCrawlerSettingsInputTextExtractor",
    "SitemapCrawlerSettingsOutput",
    "SitemapCrawlerSettingsOutputScraper",
    "SitemapCrawlerSettingsOutputTextExtractor",
    "SourceArchetype",
    "SourceSyncCrawlSettingsInput",
    "SourceSyncCrawlSettingsOutput",
    "SourceSyncNotionSettings",
    "SourceSyncPageCrawlSettingsInput",
    "SourceSyncPageCrawlSettingsOutput",
    "SourceSyncSitemapSettingsInput",
    "SourceSyncSitemapSettingsOutput",
    "SourceSyncWebsiteSettings",
    "SourceSyncWebsiteSettingsSplitter",
    "SrcHandlersCreateCopilotResponse",
    "SrcHandlersCreateWorkflowResponse",
    "SrcHandlersCreateWorkflowRevisionResponse",
    "SrcHandlersDeleteCopilotResponse",
    "SrcHandlersDeleteWorkflowResponse",
    "SrcHandlersDeleteWorkflowRevisionResponse",
    "SrcHandlersGetCopilotResponse",
    "SrcHandlersGetWorkflowEnvironmentsResponse",
    "SrcHandlersGetWorkflowResponse",
    "SrcHandlersListCopilotsResponse",
    "SrcHandlersListWorkflowRevisionsResponse",
    "SrcHandlersListWorkflowsResponse",
    "SrcHandlersPromoteWorkflowRevisionResponse",
    "SrcHandlersUpdateCopilotResponse",
    "SrcHandlersUpdateWorkflowEnvironmentResponse",
    "SrcHandlersUpdateWorkflowResponse",
    "Sync",
    "SyncConfigInput",
    "SyncConfigInputSourceSettings",
    "SyncConfigOutput",
    "SyncConfigOutputSourceSettings",
    "Table",
    "TableConfigOutput",
    "TableConfigOutputSchemaItem",
    "TextExtractor",
    "TextExtractorConfig",
    "TextLongColumn",
    "TextShortColumn",
    "TrafilaturaInput",
    "TrafilaturaInputTrafilaturaType",
    "TrafilaturaOutput",
    "TrafilaturaOutputTrafilaturaType",
    "UrlColumn",
    "Usage",
    "UserIdentity",
    "ValidationError",
    "ValidationErrorLocItem",
    "Workflow",
    "WorkflowConfigInput",
    "WorkflowConfigOutput",
    "WorkflowNoteInput",
    "WorkflowNoteOutput",
    "WorkflowRun",
    "WorkflowRunCompleted",
    "WorkflowRunCompletedData",
    "WorkflowRunCompletedEnvironment",
    "WorkflowRunFailed",
    "WorkflowRunFailedData",
    "WorkflowRunFailedEnvironment",
    "WorkflowRunResponse",
    "WorkflowRunStarted",
    "WorkflowRunStartedData",
    "WorkflowRunStartedEnvironment",
    "WorkflowRunStateValue",
    "WorkflowRunStopReason",
    "WorkflowRunStreamResponse",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .document_data_value import DocumentDataValue
from .identity import Identity


class Document(UncheckedBaseModel):
    document_id: typing.Optional[str] = None
    data: typing.Optional[typing.Dict[str, typing.Optional[DocumentDataValue]]] = None
    document_data_id: typing.Optional[str] = None
    created_at: typing.Optional[dt.datetime] = None
    last_updated_at: typing.Optional[dt.datetime] = None
    created_by: Identity
    last_updated_by: Identity
    revision_id: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .table_config_output_schema_item import TableConfigOutputSchemaItem


class TableConfigOutput(UncheckedBaseModel):
    table_display_name: typing.Optional[str] = None
    table_img_url: typing.Optional[str] = None
    table_description: typing.Optional[str] = None
    schema_: typing_extensions.Annotated[
        typing.Optional[typing.List[TableConfigOutputSchemaItem]], FieldMetadata(alias="schema")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    DocumentsCreateRequestBody,
    DocumentsCreateRequestBodyItemValue,
    DocumentsCreateRequestBodyOneValue,
    DocumentsCreateRequestBodyZeroValue,
    DocumentsUpdateRequestValue,
)

__all__ = [
    "DocumentsCreateRequestBody",
    "DocumentsCreateRequestBodyItemValue",
    "DocumentsCreateRequestBodyOneValue",
    "DocumentsCreateRequestBodyZeroValue",
    "DocumentsUpdateRequestValue",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .http import Http
from .playwright import Playwright

SinglePageCrawlerSettingsInputScraper = typing.Union[Http, Playwright]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from .raw_client import AsyncRawWorkflowLogsClient, RawWorkflowLogsClient
from .types.workflow_logs_list_logs_response import WorkflowLogsListLogsResponse


class WorkflowLogsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawWorkflowLogsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawWorkflowLogsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawWorkflowLogsClient
        """
        return self._raw_client

    def list_logs(
        self,
        *,
        workflow_id: str,
        start_date: typing.Optional[str] = None,
        end_date: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        session_id: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
        cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[WorkflowLogsListLogsResponse]:
        """
        Parameters
        ----------
        workflow_id : str

        start_date : typing.Optional[str]

        end_date : typing.Optional[str]

        limit : typing.Optional[int]

        session_id : typing.Optional[str]

        status : typing.Optional[str]

        cursor : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.Iterator[WorkflowLogsListLogsResponse]
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        response = client.workflow_logs.list_logs(
            workflow_id="workflow_id",
        )
        for chunk in response:
            yield chunk
        """
        with self._raw_client.list_logs(
            workflow_id=workflow_id,
            start_date=start_date,
            end_date=end_date,
            limit=limit,
            session_id=session_id,
            status=status,
            cursor=cursor,
            request_options=request_options,
        ) as r:
            yield from r.data


class AsyncWorkflowLogsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawWorkflowLogsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawWorkflowLogsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawWorkflowLogsClient
        """
        return self._raw_client

    async def list_logs(
        self,
        *,
        workflow_id: str,
        start_date: typing.Optional[str] = None,
        end_date: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        session_id: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
        cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[WorkflowLogsListLogsResponse]:
        """
        Parameters
        ----------
        workflow_id : str

        start_date : typing.Optional[str]

        end_date : typing.Optional[str]

        limit : typing.Optional[int]

        session_id : typing.Optional[str]

        status : typing.Optional[str]

        cursor : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.AsyncIterator[WorkflowLogsListLogsResponse]
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            response = await client.workflow_logs.list_logs(
                workflow_id="workflow_id",
            )
            async for chunk in response:
                yield chunk


        asyncio.run(main())
        """
        async with self._raw_client.list_logs(
            workflow_id=workflow_id,
            start_date=start_date,
            end_date=end_date,
            limit=limit,
            session_id=session_id,
            status=status,
            cursor=cursor,
            request_options=request_options,
        ) as r:
            async for _chunk in r.data:
                yield _chunk



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class BlockRun(UncheckedBaseModel):
    block_archetype_id: str
    block_type: str
    block_id: str
    block_display_name: typing.Optional[str] = None
    block_inputs: typing.Dict[str, typing.Optional[typing.Any]]
    block_output: typing.Optional[typing.Any] = None
    config: typing.Dict[str, typing.Optional[typing.Any]]
    metadata: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    elapsed_time_ms: typing.Optional[int] = None
    cost: typing.Optional[float] = None
    status: typing.Optional[str] = None
    timestamp_start: typing.Optional[dt.datetime] = None
    timestamp_end: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

ColumnType = typing.Union[
    typing.Literal["checkbox", "json", "number", "select", "text-long", "text-short", "url", "markdown"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .block_run import BlockRun


class RunLog(UncheckedBaseModel):
    workflow_display_name: str
    workflow_run_id: str
    workflow_id: str
    status: str
    session_id: str
    cost: float
    blocks: typing.Dict[str, BlockRun]
    output: typing.Optional[typing.Any] = None
    elapsed_time_ms: int
    timestamp_start: dt.datetime
    timestamp_end: dt.datetime
    message: typing.Optional[str] = None
    gcs_log_path: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.check_box_column import CheckBoxColumn
from ...types.json_column import JsonColumn
from ...types.markdown_column import MarkdownColumn
from ...types.number_column import NumberColumn
from ...types.select_column import SelectColumn
from ...types.text_long_column import TextLongColumn
from ...types.text_short_column import TextShortColumn
from ...types.url_column import UrlColumn

TableConfigInputSchemaItem = typing.Union[
    CheckBoxColumn, JsonColumn, MarkdownColumn, NumberColumn, SelectColumn, TextLongColumn, TextShortColumn, UrlColumn
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.collection_service_handlers_get_table_response import CollectionServiceHandlersGetTableResponse
from ...types.schema_response import SchemaResponse

TablesGetSchemaResponse = typing.Union[CollectionServiceHandlersGetTableResponse, SchemaResponse]



# This file was auto-generated by Fern from our API Definition.

import typing

from .custom import Custom
from .readability import Readability
from .trafilatura_output import TrafilaturaOutput

SinglePageCrawlerSettingsOutputTextExtractor = typing.Union[Custom, Readability, TrafilaturaOutput]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.request_options import RequestOptions
from ..core.unchecked_base_model import construct_type
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.collection_service_handlers_create_collection_response import (
    CollectionServiceHandlersCreateCollectionResponse,
)
from ..types.collection_service_handlers_delete_collection_response import (
    CollectionServiceHandlersDeleteCollectionResponse,
)
from ..types.collection_service_handlers_get_collection_response import CollectionServiceHandlersGetCollectionResponse
from ..types.collection_service_handlers_get_collections_response import CollectionServiceHandlersGetCollectionsResponse
from ..types.collection_service_handlers_update_collection_response import (
    CollectionServiceHandlersUpdateCollectionResponse,
)
from ..types.http_validation_error import HttpValidationError

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawCollectionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        *,
        start_at: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        query: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CollectionServiceHandlersGetCollectionsResponse]:
        """
        Parameters
        ----------
        start_at : typing.Optional[str]
            created_at to start at

        limit : typing.Optional[int]
            Limit of records to return

        query : typing.Optional[str]
            Search query

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CollectionServiceHandlersGetCollectionsResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v2/collections",
            method="GET",
            params={
                "start_at": start_at,
                "limit": limit,
                "query": query,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersGetCollectionsResponse,
                    construct_type(
                        type_=CollectionServiceHandlersGetCollectionsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self,
        *,
        collection_display_name: typing.Optional[str] = OMIT,
        collection_img_url: typing.Optional[str] = OMIT,
        collection_description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CollectionServiceHandlersCreateCollectionResponse]:
        """
        Parameters
        ----------
        collection_display_name : typing.Optional[str]

        collection_img_url : typing.Optional[str]

        collection_description : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CollectionServiceHandlersCreateCollectionResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v2/collections",
            method="POST",
            json={
                "collection_display_name": collection_display_name,
                "collection_img_url": collection_img_url,
                "collection_description": collection_description,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersCreateCollectionResponse,
                    construct_type(
                        type_=CollectionServiceHandlersCreateCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[CollectionServiceHandlersGetCollectionResponse]:
        """
        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CollectionServiceHandlersGetCollectionResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersGetCollectionResponse,
                    construct_type(
                        type_=CollectionServiceHandlersGetCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        collection_id: str,
        *,
        collection_display_name: typing.Optional[str] = OMIT,
        collection_img_url: typing.Optional[str] = OMIT,
        collection_description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CollectionServiceHandlersUpdateCollectionResponse]:
        """
        Parameters
        ----------
        collection_id : str

        collection_display_name : typing.Optional[str]

        collection_img_url : typing.Optional[str]

        collection_description : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CollectionServiceHandlersUpdateCollectionResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}",
            method="PUT",
            json={
                "collection_display_name": collection_display_name,
                "collection_img_url": collection_img_url,
                "collection_description": collection_description,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersUpdateCollectionResponse,
                    construct_type(
                        type_=CollectionServiceHandlersUpdateCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[CollectionServiceHandlersDeleteCollectionResponse]:
        """
        Delete a collection given a collection_id.

        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CollectionServiceHandlersDeleteCollectionResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersDeleteCollectionResponse,
                    construct_type(
                        type_=CollectionServiceHandlersDeleteCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawCollectionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        *,
        start_at: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        query: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CollectionServiceHandlersGetCollectionsResponse]:
        """
        Parameters
        ----------
        start_at : typing.Optional[str]
            created_at to start at

        limit : typing.Optional[int]
            Limit of records to return

        query : typing.Optional[str]
            Search query

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CollectionServiceHandlersGetCollectionsResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v2/collections",
            method="GET",
            params={
                "start_at": start_at,
                "limit": limit,
                "query": query,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersGetCollectionsResponse,
                    construct_type(
                        type_=CollectionServiceHandlersGetCollectionsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self,
        *,
        collection_display_name: typing.Optional[str] = OMIT,
        collection_img_url: typing.Optional[str] = OMIT,
        collection_description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CollectionServiceHandlersCreateCollectionResponse]:
        """
        Parameters
        ----------
        collection_display_name : typing.Optional[str]

        collection_img_url : typing.Optional[str]

        collection_description : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CollectionServiceHandlersCreateCollectionResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v2/collections",
            method="POST",
            json={
                "collection_display_name": collection_display_name,
                "collection_img_url": collection_img_url,
                "collection_description": collection_description,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersCreateCollectionResponse,
                    construct_type(
                        type_=CollectionServiceHandlersCreateCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[CollectionServiceHandlersGetCollectionResponse]:
        """
        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CollectionServiceHandlersGetCollectionResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersGetCollectionResponse,
                    construct_type(
                        type_=CollectionServiceHandlersGetCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        collection_id: str,
        *,
        collection_display_name: typing.Optional[str] = OMIT,
        collection_img_url: typing.Optional[str] = OMIT,
        collection_description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CollectionServiceHandlersUpdateCollectionResponse]:
        """
        Parameters
        ----------
        collection_id : str

        collection_display_name : typing.Optional[str]

        collection_img_url : typing.Optional[str]

        collection_description : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CollectionServiceHandlersUpdateCollectionResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}",
            method="PUT",
            json={
                "collection_display_name": collection_display_name,
                "collection_img_url": collection_img_url,
                "collection_description": collection_description,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersUpdateCollectionResponse,
                    construct_type(
                        type_=CollectionServiceHandlersUpdateCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[CollectionServiceHandlersDeleteCollectionResponse]:
        """
        Delete a collection given a collection_id.

        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CollectionServiceHandlersDeleteCollectionResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersDeleteCollectionResponse,
                    construct_type(
                        type_=CollectionServiceHandlersDeleteCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    Actor,
    ActorType,
    ApiKeyIdentity,
    BareInput,
    BareOutput,
    Baseline,
    BlockConfigItemBoolean,
    BlockConfigItemJson,
    BlockConfigItemLlm,
    BlockConfigItemNumber,
    BlockConfigItemNumberDefaultValue,
    BlockConfigItemNumberMaximumValue,
    BlockConfigItemNumberMinimumValue,
    BlockConfigItemNumberValue,
    BlockConfigItemSelect,
    BlockConfigItemTextLong,
    BlockConfigItemTextLongValue,
    BlockConfigItemTextShort,
    BlockInput,
    BlockInputBlockConfigItem,
    BlockOutput,
    BlockOutputBlockConfigItem,
    BlockRun,
    BlockRunCompleted,
    BlockRunCompletedData,
    BlockRunCompletedEnvironment,
    BlockRunFailed,
    BlockRunFailedData,
    BlockRunFailedEnvironment,
    BlockRunStarted,
    BlockRunStartedData,
    BlockRunStartedEnvironment,
    BlockRunUsage,
    BlockStateUpdated,
    BlockStateUpdatedData,
    BlockStateUpdatedDataUpdateType,
    BlockStateUpdatedEnvironment,
    CheckBoxColumn,
    Collection,
    CollectionConfig,
    CollectionDestination,
    CollectionServiceHandlersCreateCollectionResponse,
    CollectionServiceHandlersCreateSyncResponse,
    CollectionServiceHandlersCreateTableResponse,
    CollectionServiceHandlersDeleteCollectionResponse,
    CollectionServiceHandlersDeleteDocumentsResponse,
    CollectionServiceHandlersDeleteSyncResponse,
    CollectionServiceHandlersDeleteTableResponse,
    CollectionServiceHandlersGetCollectionResponse,
    CollectionServiceHandlersGetCollectionsResponse,
    CollectionServiceHandlersGetDocumentResponse,
    CollectionServiceHandlersGetDocumentsResponse,
    CollectionServiceHandlersGetSyncResponse,
    CollectionServiceHandlersGetTableResponse,
    CollectionServiceHandlersGetTablesResponse,
    CollectionServiceHandlersListCollectionSyncsResponseModel,
    CollectionServiceHandlersListSourceArchetypesResponseModel,
    CollectionServiceHandlersTableSyncResponse,
    CollectionServiceHandlersUpdateCollectionResponse,
    CollectionServiceHandlersUpdateDocumentResponse,
    CollectionServiceHandlersUpdateSyncResponse,
    CollectionServiceHandlersUpdateTableResponse,
    ColumnType,
    ColumnTypeBase,
    Copilot,
    CopilotConfig,
    CopilotConfigCodeTheme,
    CopilotConfigFabValue,
    CopilotConfigMode,
    Custom,
    DataType,
    DefaultInput,
    DefaultOutput,
    Dependency,
    Dimensions,
    Document,
    DocumentDataValue,
    DocumentResponse,
    EdgeUi,
    Environment,
    EnvironmentConfig,
    EnvironmentDeploymentConfig,
    EnvironmentDeploymentConfigRevisionLookup,
    EnvironmentDeploymentDocument,
    EventVersion,
    Favor,
    Html2Text,
    Http,
    HttpValidationError,
    Identity,
    IdentityDetails,
    IdentityTypes,
    JsonColumn,
    Mapping,
    MarkDownWithContext,
    MarkdownColumn,
    MarkdownSplitterConfig,
    Message,
    MessageChunk,
    MultiPageCrawlerSettingsInput,
    MultiPageCrawlerSettingsInputScraper,
    MultiPageCrawlerSettingsInputTextExtractor,
    MultiPageCrawlerSettingsOutput,
    MultiPageCrawlerSettingsOutputScraper,
    MultiPageCrawlerSettingsOutputTextExtractor,
    NodeUi,
    NumberColumn,
    NumberColumnDefault,
    NumberColumnMaxValue,
    NumberColumnMinValue,
    ParagraphSplitterConfig,
    PlaceholderInput,
    PlaceholderInputType,
    PlaceholderOutput,
    PlaceholderOutputType,
    Playwright,
    PlaywrightWaitForLoadState,
    Position,
    Prompt,
    PromptRole,
    Readability,
    RecursiveSplitterConfig,
    ReqBody,
    RequestBody,
    ResponseModelUsage,
    RunLog,
    RunLogPagination,
    Schedule,
    SchemaResponse,
    SelectColumn,
    SelectOptionItem,
    SentenceSplitterConfig,
    SinglePageCrawlerSettingsInput,
    SinglePageCrawlerSettingsInputScraper,
    SinglePageCrawlerSettingsInputTextExtractor,
    SinglePageCrawlerSettingsOutput,
    SinglePageCrawlerSettingsOutputScraper,
    SinglePageCrawlerSettingsOutputTextExtractor,
    SitemapCrawlerSettingsInput,
    SitemapCrawlerSettingsInputScraper,
    SitemapCrawlerSettingsInputTextExtractor,
    SitemapCrawlerSettingsOutput,
    SitemapCrawlerSettingsOutputScraper,
    SitemapCrawlerSettingsOutputTextExtractor,
    SourceArchetype,
    SourceSyncCrawlSettingsInput,
    SourceSyncCrawlSettingsOutput,
    SourceSyncNotionSettings,
    SourceSyncPageCrawlSettingsInput,
    SourceSyncPageCrawlSettingsOutput,
    SourceSyncSitemapSettingsInput,
    SourceSyncSitemapSettingsOutput,
    SourceSyncWebsiteSettings,
    SourceSyncWebsiteSettingsSplitter,
    SrcHandlersCreateCopilotResponse,
    SrcHandlersCreateWorkflowResponse,
    SrcHandlersCreateWorkflowRevisionResponse,
    SrcHandlersDeleteCopilotResponse,
    SrcHandlersDeleteWorkflowResponse,
    SrcHandlersDeleteWorkflowRevisionResponse,
    SrcHandlersGetCopilotResponse,
    SrcHandlersGetWorkflowEnvironmentsResponse,
    SrcHandlersGetWorkflowResponse,
    SrcHandlersListCopilotsResponse,
    SrcHandlersListWorkflowRevisionsResponse,
    SrcHandlersListWorkflowsResponse,
    SrcHandlersPromoteWorkflowRevisionResponse,
    SrcHandlersUpdateCopilotResponse,
    SrcHandlersUpdateWorkflowEnvironmentResponse,
    SrcHandlersUpdateWorkflowResponse,
    Sync,
    SyncConfigInput,
    SyncConfigInputSourceSettings,
    SyncConfigOutput,
    SyncConfigOutputSourceSettings,
    Table,
    TableConfigOutput,
    TableConfigOutputSchemaItem,
    TextExtractor,
    TextExtractorConfig,
    TextLongColumn,
    TextShortColumn,
    TrafilaturaInput,
    TrafilaturaInputTrafilaturaType,
    TrafilaturaOutput,
    TrafilaturaOutputTrafilaturaType,
    UrlColumn,
    Usage,
    UserIdentity,
    ValidationError,
    ValidationErrorLocItem,
    Workflow,
    WorkflowConfigInput,
    WorkflowConfigOutput,
    WorkflowNoteInput,
    WorkflowNoteOutput,
    WorkflowRun,
    WorkflowRunCompleted,
    WorkflowRunCompletedData,
    WorkflowRunCompletedEnvironment,
    WorkflowRunFailed,
    WorkflowRunFailedData,
    WorkflowRunFailedEnvironment,
    WorkflowRunResponse,
    WorkflowRunStarted,
    WorkflowRunStartedData,
    WorkflowRunStartedEnvironment,
    WorkflowRunStateValue,
    WorkflowRunStopReason,
    WorkflowRunStreamResponse,
)
from .errors import UnprocessableEntityError
from . import (
    collections,
    copilots,
    documents,
    environments,
    revisions,
    sources,
    syncs,
    tables,
    usage,
    workflow_logs,
    workflows,
)
from .client import AsyncScout, Scout
from .documents import (
    DocumentsCreateRequestBody,
    DocumentsCreateRequestBodyItemValue,
    DocumentsCreateRequestBodyOneValue,
    DocumentsCreateRequestBodyZeroValue,
    DocumentsUpdateRequestValue,
)
from .environment import ScoutEnvironment
from .tables import TableConfigInputSchemaItem, TableDataSchemaItem, TablesGetSchemaResponse
from .version import __version__
from .workflow_logs import WorkflowLogsListLogsResponse
from .workflows import (
    SrcHandlersWorkflowsExecuteWithConfigReqBodyInputsValue,
    WorkflowsRunRequestInputsValue,
    WorkflowsRunStreamRequestInputsValue,
    WorkflowsRunWithConfigResponse,
    WorkflowsRunWithConfigResponseZero,
)

__all__ = [
    "Actor",
    "ActorType",
    "ApiKeyIdentity",
    "AsyncScout",
    "BareInput",
    "BareOutput",
    "Baseline",
    "BlockConfigItemBoolean",
    "BlockConfigItemJson",
    "BlockConfigItemLlm",
    "BlockConfigItemNumber",
    "BlockConfigItemNumberDefaultValue",
    "BlockConfigItemNumberMaximumValue",
    "BlockConfigItemNumberMinimumValue",
    "BlockConfigItemNumberValue",
    "BlockConfigItemSelect",
    "BlockConfigItemTextLong",
    "BlockConfigItemTextLongValue",
    "BlockConfigItemTextShort",
    "BlockInput",
    "BlockInputBlockConfigItem",
    "BlockOutput",
    "BlockOutputBlockConfigItem",
    "BlockRun",
    "BlockRunCompleted",
    "BlockRunCompletedData",
    "BlockRunCompletedEnvironment",
    "BlockRunFailed",
    "BlockRunFailedData",
    "BlockRunFailedEnvironment",
    "BlockRunStarted",
    "BlockRunStartedData",
    "BlockRunStartedEnvironment",
    "BlockRunUsage",
    "BlockStateUpdated",
    "BlockStateUpdatedData",
    "BlockStateUpdatedDataUpdateType",
    "BlockStateUpdatedEnvironment",
    "CheckBoxColumn",
    "Collection",
    "CollectionConfig",
    "CollectionDestination",
    "CollectionServiceHandlersCreateCollectionResponse",
    "CollectionServiceHandlersCreateSyncResponse",
    "CollectionServiceHandlersCreateTableResponse",
    "CollectionServiceHandlersDeleteCollectionResponse",
    "CollectionServiceHandlersDeleteDocumentsResponse",
    "CollectionServiceHandlersDeleteSyncResponse",
    "CollectionServiceHandlersDeleteTableResponse",
    "CollectionServiceHandlersGetCollectionResponse",
    "CollectionServiceHandlersGetCollectionsResponse",
    "CollectionServiceHandlersGetDocumentResponse",
    "CollectionServiceHandlersGetDocumentsResponse",
    "CollectionServiceHandlersGetSyncResponse",
    "CollectionServiceHandlersGetTableResponse",
    "CollectionServiceHandlersGetTablesResponse",
    "CollectionServiceHandlersListCollectionSyncsResponseModel",
    "CollectionServiceHandlersListSourceArchetypesResponseModel",
    "CollectionServiceHandlersTableSyncResponse",
    "CollectionServiceHandlersUpdateCollectionResponse",
    "CollectionServiceHandlersUpdateDocumentResponse",
    "CollectionServiceHandlersUpdateSyncResponse",
    "CollectionServiceHandlersUpdateTableResponse",
    "ColumnType",
    "ColumnTypeBase",
    "Copilot",
    "CopilotConfig",
    "CopilotConfigCodeTheme",
    "CopilotConfigFabValue",
    "CopilotConfigMode",
    "Custom",
    "DataType",
    "DefaultInput",
    "DefaultOutput",
    "Dependency",
    "Dimensions",
    "Document",
    "DocumentDataValue",
    "DocumentResponse",
    "DocumentsCreateRequestBody",
    "DocumentsCreateRequestBodyItemValue",
    "DocumentsCreateRequestBodyOneValue",
    "DocumentsCreateRequestBodyZeroValue",
    "DocumentsUpdateRequestValue",
    "EdgeUi",
    "Environment",
    "EnvironmentConfig",
    "EnvironmentDeploymentConfig",
    "EnvironmentDeploymentConfigRevisionLookup",
    "EnvironmentDeploymentDocument",
    "EventVersion",
    "Favor",
    "Html2Text",
    "Http",
    "HttpValidationError",
    "Identity",
    "IdentityDetails",
    "IdentityTypes",
    "JsonColumn",
    "Mapping",
    "MarkDownWithContext",
    "MarkdownColumn",
    "MarkdownSplitterConfig",
    "Message",
    "MessageChunk",
    "MultiPageCrawlerSettingsInput",
    "MultiPageCrawlerSettingsInputScraper",
    "MultiPageCrawlerSettingsInputTextExtractor",
    "MultiPageCrawlerSettingsOutput",
    "MultiPageCrawlerSettingsOutputScraper",
    "MultiPageCrawlerSettingsOutputTextExtractor",
    "NodeUi",
    "NumberColumn",
    "NumberColumnDefault",
    "NumberColumnMaxValue",
    "NumberColumnMinValue",
    "ParagraphSplitterConfig",
    "PlaceholderInput",
    "PlaceholderInputType",
    "PlaceholderOutput",
    "PlaceholderOutputType",
    "Playwright",
    "PlaywrightWaitForLoadState",
    "Position",
    "Prompt",
    "PromptRole",
    "Readability",
    "RecursiveSplitterConfig",
    "ReqBody",
    "RequestBody",
    "ResponseModelUsage",
    "RunLog",
    "RunLogPagination",
    "Schedule",
    "SchemaResponse",
    "Scout",
    "ScoutEnvironment",
    "SelectColumn",
    "SelectOptionItem",
    "SentenceSplitterConfig",
    "SinglePageCrawlerSettingsInput",
    "SinglePageCrawlerSettingsInputScraper",
    "SinglePageCrawlerSettingsInputTextExtractor",
    "SinglePageCrawlerSettingsOutput",
    "SinglePageCrawlerSettingsOutputScraper",
    "SinglePageCrawlerSettingsOutputTextExtractor",
    "SitemapCrawlerSettingsInput",
    "SitemapCrawlerSettingsInputScraper",
    "SitemapCrawlerSettingsInputTextExtractor",
    "SitemapCrawlerSettingsOutput",
    "SitemapCrawlerSettingsOutputScraper",
    "SitemapCrawlerSettingsOutputTextExtractor",
    "SourceArchetype",
    "SourceSyncCrawlSettingsInput",
    "SourceSyncCrawlSettingsOutput",
    "SourceSyncNotionSettings",
    "SourceSyncPageCrawlSettingsInput",
    "SourceSyncPageCrawlSettingsOutput",
    "SourceSyncSitemapSettingsInput",
    "SourceSyncSitemapSettingsOutput",
    "SourceSyncWebsiteSettings",
    "SourceSyncWebsiteSettingsSplitter",
    "SrcHandlersCreateCopilotResponse",
    "SrcHandlersCreateWorkflowResponse",
    "SrcHandlersCreateWorkflowRevisionResponse",
    "SrcHandlersDeleteCopilotResponse",
    "SrcHandlersDeleteWorkflowResponse",
    "SrcHandlersDeleteWorkflowRevisionResponse",
    "SrcHandlersGetCopilotResponse",
    "SrcHandlersGetWorkflowEnvironmentsResponse",
    "SrcHandlersGetWorkflowResponse",
    "SrcHandlersListCopilotsResponse",
    "SrcHandlersListWorkflowRevisionsResponse",
    "SrcHandlersListWorkflowsResponse",
    "SrcHandlersPromoteWorkflowRevisionResponse",
    "SrcHandlersUpdateCopilotResponse",
    "SrcHandlersUpdateWorkflowEnvironmentResponse",
    "SrcHandlersUpdateWorkflowResponse",
    "SrcHandlersWorkflowsExecuteWithConfigReqBodyInputsValue",
    "Sync",
    "SyncConfigInput",
    "SyncConfigInputSourceSettings",
    "SyncConfigOutput",
    "SyncConfigOutputSourceSettings",
    "Table",
    "TableConfigInputSchemaItem",
    "TableConfigOutput",
    "TableConfigOutputSchemaItem",
    "TableDataSchemaItem",
    "TablesGetSchemaResponse",
    "TextExtractor",
    "TextExtractorConfig",
    "TextLongColumn",
    "TextShortColumn",
    "TrafilaturaInput",
    "TrafilaturaInputTrafilaturaType",
    "TrafilaturaOutput",
    "TrafilaturaOutputTrafilaturaType",
    "UnprocessableEntityError",
    "UrlColumn",
    "Usage",
    "UserIdentity",
    "ValidationError",
    "ValidationErrorLocItem",
    "Workflow",
    "WorkflowConfigInput",
    "WorkflowConfigOutput",
    "WorkflowLogsListLogsResponse",
    "WorkflowNoteInput",
    "WorkflowNoteOutput",
    "WorkflowRun",
    "WorkflowRunCompleted",
    "WorkflowRunCompletedData",
    "WorkflowRunCompletedEnvironment",
    "WorkflowRunFailed",
    "WorkflowRunFailedData",
    "WorkflowRunFailedEnvironment",
    "WorkflowRunResponse",
    "WorkflowRunStarted",
    "WorkflowRunStartedData",
    "WorkflowRunStartedEnvironment",
    "WorkflowRunStateValue",
    "WorkflowRunStopReason",
    "WorkflowRunStreamResponse",
    "WorkflowsRunRequestInputsValue",
    "WorkflowsRunStreamRequestInputsValue",
    "WorkflowsRunWithConfigResponse",
    "WorkflowsRunWithConfigResponseZero",
    "__version__",
    "collections",
    "copilots",
    "documents",
    "environments",
    "revisions",
    "sources",
    "syncs",
    "tables",
    "usage",
    "workflow_logs",
    "workflows",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .mark_down_with_context import MarkDownWithContext
from .markdown_splitter_config import MarkdownSplitterConfig
from .paragraph_splitter_config import ParagraphSplitterConfig
from .recursive_splitter_config import RecursiveSplitterConfig
from .sentence_splitter_config import SentenceSplitterConfig

SourceSyncWebsiteSettingsSplitter = typing.Union[
    MarkdownSplitterConfig,
    RecursiveSplitterConfig,
    SentenceSplitterConfig,
    ParagraphSplitterConfig,
    MarkDownWithContext,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .number_column_default import NumberColumnDefault
from .number_column_max_value import NumberColumnMaxValue
from .number_column_min_value import NumberColumnMinValue


class NumberColumn(UncheckedBaseModel):
    column_id: typing.Optional[str] = None
    column_display_name: typing.Optional[str] = None
    column_type: typing.Literal["number"] = "number"
    data_type: typing.Optional[typing.Literal["number"]] = None
    hidden: typing.Optional[bool] = None
    default: typing.Optional[NumberColumnDefault] = None
    min_value: typing.Optional[NumberColumnMinValue] = None
    max_value: typing.Optional[NumberColumnMaxValue] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import TableConfigInputSchemaItem, TableDataSchemaItem, TablesGetSchemaResponse

__all__ = ["TableConfigInputSchemaItem", "TableDataSchemaItem", "TablesGetSchemaResponse"]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .src_handlers_workflows_execute_with_config_req_body_inputs_value import (
    SrcHandlersWorkflowsExecuteWithConfigReqBodyInputsValue,
)
from .workflows_run_request_inputs_value import WorkflowsRunRequestInputsValue
from .workflows_run_stream_request_inputs_value import WorkflowsRunStreamRequestInputsValue
from .workflows_run_with_config_response import WorkflowsRunWithConfigResponse
from .workflows_run_with_config_response_zero import WorkflowsRunWithConfigResponseZero

__all__ = [
    "SrcHandlersWorkflowsExecuteWithConfigReqBodyInputsValue",
    "WorkflowsRunRequestInputsValue",
    "WorkflowsRunStreamRequestInputsValue",
    "WorkflowsRunWithConfigResponse",
    "WorkflowsRunWithConfigResponseZero",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..core.unchecked_base_model import construct_type
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.collection_service_handlers_create_sync_response import CollectionServiceHandlersCreateSyncResponse
from ..types.collection_service_handlers_delete_sync_response import CollectionServiceHandlersDeleteSyncResponse
from ..types.collection_service_handlers_get_sync_response import CollectionServiceHandlersGetSyncResponse
from ..types.collection_service_handlers_list_collection_syncs_response_model import (
    CollectionServiceHandlersListCollectionSyncsResponseModel,
)
from ..types.collection_service_handlers_update_sync_response import CollectionServiceHandlersUpdateSyncResponse
from ..types.http_validation_error import HttpValidationError
from ..types.sync_config_input import SyncConfigInput

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawSyncsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get(
        self, sync_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[CollectionServiceHandlersGetSyncResponse]:
        """
        Parameters
        ----------
        sync_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CollectionServiceHandlersGetSyncResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/syncs/{jsonable_encoder(sync_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersGetSyncResponse,
                    construct_type(
                        type_=CollectionServiceHandlersGetSyncResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self, sync_id: str, *, sync_config: SyncConfigInput, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[CollectionServiceHandlersUpdateSyncResponse]:
        """
        Parameters
        ----------
        sync_id : str

        sync_config : SyncConfigInput

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CollectionServiceHandlersUpdateSyncResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/syncs/{jsonable_encoder(sync_id)}",
            method="PUT",
            json={
                "sync_config": convert_and_respect_annotation_metadata(
                    object_=sync_config, annotation=SyncConfigInput, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersUpdateSyncResponse,
                    construct_type(
                        type_=CollectionServiceHandlersUpdateSyncResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self, sync_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[CollectionServiceHandlersDeleteSyncResponse]:
        """
        Parameters
        ----------
        sync_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CollectionServiceHandlersDeleteSyncResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/syncs/{jsonable_encoder(sync_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersDeleteSyncResponse,
                    construct_type(
                        type_=CollectionServiceHandlersDeleteSyncResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def list(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[CollectionServiceHandlersListCollectionSyncsResponseModel]:
        """
        List Sources by Destination, specifically given a collection and table

        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CollectionServiceHandlersListCollectionSyncsResponseModel]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/syncs",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersListCollectionSyncsResponseModel,
                    construct_type(
                        type_=CollectionServiceHandlersListCollectionSyncsResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self, *, sync_config: SyncConfigInput, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[CollectionServiceHandlersCreateSyncResponse]:
        """
        Parameters
        ----------
        sync_config : SyncConfigInput

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CollectionServiceHandlersCreateSyncResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v2/syncs",
            method="POST",
            json={
                "sync_config": convert_and_respect_annotation_metadata(
                    object_=sync_config, annotation=SyncConfigInput, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersCreateSyncResponse,
                    construct_type(
                        type_=CollectionServiceHandlersCreateSyncResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def execute(
        self, sync_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[typing.Optional[typing.Any]]:
        """
        Parameters
        ----------
        sync_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Optional[typing.Any]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/syncs/{jsonable_encoder(sync_id)}/execute",
            method="POST",
            request_options=request_options,
        )
        try:
            if _response is None or not _response.text.strip():
                return HttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Optional[typing.Any],
                    construct_type(
                        type_=typing.Optional[typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawSyncsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get(
        self, sync_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[CollectionServiceHandlersGetSyncResponse]:
        """
        Parameters
        ----------
        sync_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CollectionServiceHandlersGetSyncResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/syncs/{jsonable_encoder(sync_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersGetSyncResponse,
                    construct_type(
                        type_=CollectionServiceHandlersGetSyncResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self, sync_id: str, *, sync_config: SyncConfigInput, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[CollectionServiceHandlersUpdateSyncResponse]:
        """
        Parameters
        ----------
        sync_id : str

        sync_config : SyncConfigInput

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CollectionServiceHandlersUpdateSyncResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/syncs/{jsonable_encoder(sync_id)}",
            method="PUT",
            json={
                "sync_config": convert_and_respect_annotation_metadata(
                    object_=sync_config, annotation=SyncConfigInput, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersUpdateSyncResponse,
                    construct_type(
                        type_=CollectionServiceHandlersUpdateSyncResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self, sync_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[CollectionServiceHandlersDeleteSyncResponse]:
        """
        Parameters
        ----------
        sync_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CollectionServiceHandlersDeleteSyncResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/syncs/{jsonable_encoder(sync_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersDeleteSyncResponse,
                    construct_type(
                        type_=CollectionServiceHandlersDeleteSyncResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def list(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[CollectionServiceHandlersListCollectionSyncsResponseModel]:
        """
        List Sources by Destination, specifically given a collection and table

        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CollectionServiceHandlersListCollectionSyncsResponseModel]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/syncs",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersListCollectionSyncsResponseModel,
                    construct_type(
                        type_=CollectionServiceHandlersListCollectionSyncsResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self, *, sync_config: SyncConfigInput, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[CollectionServiceHandlersCreateSyncResponse]:
        """
        Parameters
        ----------
        sync_config : SyncConfigInput

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CollectionServiceHandlersCreateSyncResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v2/syncs",
            method="POST",
            json={
                "sync_config": convert_and_respect_annotation_metadata(
                    object_=sync_config, annotation=SyncConfigInput, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CollectionServiceHandlersCreateSyncResponse,
                    construct_type(
                        type_=CollectionServiceHandlersCreateSyncResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def execute(
        self, sync_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[typing.Optional[typing.Any]]:
        """
        Parameters
        ----------
        sync_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Optional[typing.Any]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/syncs/{jsonable_encoder(sync_id)}/execute",
            method="POST",
            request_options=request_options,
        )
        try:
            if _response is None or not _response.text.strip():
                return AsyncHttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Optional[typing.Any],
                    construct_type(
                        type_=typing.Optional[typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import contextlib
import json
import typing
from json.decoder import JSONDecodeError

import httpx_sse
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.request_options import RequestOptions
from ..core.unchecked_base_model import construct_type
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from .types.workflow_logs_list_logs_response import WorkflowLogsListLogsResponse


class RawWorkflowLogsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    @contextlib.contextmanager
    def list_logs(
        self,
        *,
        workflow_id: str,
        start_date: typing.Optional[str] = None,
        end_date: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        session_id: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
        cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[HttpResponse[typing.Iterator[WorkflowLogsListLogsResponse]]]:
        """
        Parameters
        ----------
        workflow_id : str

        start_date : typing.Optional[str]

        end_date : typing.Optional[str]

        limit : typing.Optional[int]

        session_id : typing.Optional[str]

        status : typing.Optional[str]

        cursor : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.Iterator[HttpResponse[typing.Iterator[WorkflowLogsListLogsResponse]]]
            Successful Response
        """
        with self._client_wrapper.httpx_client.stream(
            "v2/run_logs",
            method="GET",
            params={
                "workflow_id": workflow_id,
                "start_date": start_date,
                "end_date": end_date,
                "limit": limit,
                "session_id": session_id,
                "status": status,
                "cursor": cursor,
            },
            request_options=request_options,
        ) as _response:

            def _stream() -> HttpResponse[typing.Iterator[WorkflowLogsListLogsResponse]]:
                try:
                    if 200 <= _response.status_code < 300:

                        def _iter():
                            _event_source = httpx_sse.EventSource(_response)
                            for _sse in _event_source.iter_sse():
                                if _sse.data == None:
                                    return
                                try:
                                    yield typing.cast(
                                        WorkflowLogsListLogsResponse,
                                        construct_type(
                                            type_=WorkflowLogsListLogsResponse,  # type: ignore
                                            object_=json.loads(_sse.data),
                                        ),
                                    )
                                except Exception:
                                    pass
                            return

                        return HttpResponse(response=_response, data=_iter())
                    _response.read()
                    if _response.status_code == 422:
                        raise UnprocessableEntityError(
                            headers=dict(_response.headers),
                            body=typing.cast(
                                HttpValidationError,
                                construct_type(
                                    type_=HttpValidationError,  # type: ignore
                                    object_=_response.json(),
                                ),
                            ),
                        )
                    _response_json = _response.json()
                except JSONDecodeError:
                    raise ApiError(
                        status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
                    )
                raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

            yield _stream()


class AsyncRawWorkflowLogsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    @contextlib.asynccontextmanager
    async def list_logs(
        self,
        *,
        workflow_id: str,
        start_date: typing.Optional[str] = None,
        end_date: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        session_id: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
        cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[AsyncHttpResponse[typing.AsyncIterator[WorkflowLogsListLogsResponse]]]:
        """
        Parameters
        ----------
        workflow_id : str

        start_date : typing.Optional[str]

        end_date : typing.Optional[str]

        limit : typing.Optional[int]

        session_id : typing.Optional[str]

        status : typing.Optional[str]

        cursor : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Yields
        ------
        typing.AsyncIterator[AsyncHttpResponse[typing.AsyncIterator[WorkflowLogsListLogsResponse]]]
            Successful Response
        """
        async with self._client_wrapper.httpx_client.stream(
            "v2/run_logs",
            method="GET",
            params={
                "workflow_id": workflow_id,
                "start_date": start_date,
                "end_date": end_date,
                "limit": limit,
                "session_id": session_id,
                "status": status,
                "cursor": cursor,
            },
            request_options=request_options,
        ) as _response:

            async def _stream() -> AsyncHttpResponse[typing.AsyncIterator[WorkflowLogsListLogsResponse]]:
                try:
                    if 200 <= _response.status_code < 300:

                        async def _iter():
                            _event_source = httpx_sse.EventSource(_response)
                            async for _sse in _event_source.aiter_sse():
                                if _sse.data == None:
                                    return
                                try:
                                    yield typing.cast(
                                        WorkflowLogsListLogsResponse,
                                        construct_type(
                                            type_=WorkflowLogsListLogsResponse,  # type: ignore
                                            object_=json.loads(_sse.data),
                                        ),
                                    )
                                except Exception:
                                    pass
                            return

                        return AsyncHttpResponse(response=_response, data=_iter())
                    await _response.aread()
                    if _response.status_code == 422:
                        raise UnprocessableEntityError(
                            headers=dict(_response.headers),
                            body=typing.cast(
                                HttpValidationError,
                                construct_type(
                                    type_=HttpValidationError,  # type: ignore
                                    object_=_response.json(),
                                ),
                            ),
                        )
                    _response_json = _response.json()
                except JSONDecodeError:
                    raise ApiError(
                        status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
                    )
                raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

            yield await _stream()



# This file was auto-generated by Fern from our API Definition.

import os
import typing

import httpx
from .collections.client import AsyncCollectionsClient, CollectionsClient
from .copilots.client import AsyncCopilotsClient, CopilotsClient
from .core.api_error import ApiError
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .documents.client import AsyncDocumentsClient, DocumentsClient
from .environment import ScoutEnvironment
from .environments.client import AsyncEnvironmentsClient, EnvironmentsClient
from .revisions.client import AsyncRevisionsClient, RevisionsClient
from .sources.client import AsyncSourcesClient, SourcesClient
from .syncs.client import AsyncSyncsClient, SyncsClient
from .tables.client import AsyncTablesClient, TablesClient
from .usage.client import AsyncUsageClient, UsageClient
from .workflow_logs.client import AsyncWorkflowLogsClient, WorkflowLogsClient
from .workflows.client import AsyncWorkflowsClient, WorkflowsClient


class Scout:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ScoutEnvironment
        The environment to use for requests from the client. from .environment import ScoutEnvironment



        Defaults to ScoutEnvironment.PROD



    api_key : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from scoutos import Scout

    client = Scout(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ScoutEnvironment = ScoutEnvironment.PROD,
        api_key: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = os.getenv("SCOUT_API_KEY"),
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        if api_key is None:
            raise ApiError(body="The client must be instantiated be either passing in api_key or setting SCOUT_API_KEY")
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.workflows = WorkflowsClient(client_wrapper=self._client_wrapper)
        self.environments = EnvironmentsClient(client_wrapper=self._client_wrapper)
        self.revisions = RevisionsClient(client_wrapper=self._client_wrapper)
        self.usage = UsageClient(client_wrapper=self._client_wrapper)
        self.workflow_logs = WorkflowLogsClient(client_wrapper=self._client_wrapper)
        self.copilots = CopilotsClient(client_wrapper=self._client_wrapper)
        self.collections = CollectionsClient(client_wrapper=self._client_wrapper)
        self.tables = TablesClient(client_wrapper=self._client_wrapper)
        self.documents = DocumentsClient(client_wrapper=self._client_wrapper)
        self.sources = SourcesClient(client_wrapper=self._client_wrapper)
        self.syncs = SyncsClient(client_wrapper=self._client_wrapper)


class AsyncScout:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ScoutEnvironment
        The environment to use for requests from the client. from .environment import ScoutEnvironment



        Defaults to ScoutEnvironment.PROD



    api_key : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from scoutos import AsyncScout

    client = AsyncScout(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ScoutEnvironment = ScoutEnvironment.PROD,
        api_key: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = os.getenv("SCOUT_API_KEY"),
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        if api_key is None:
            raise ApiError(body="The client must be instantiated be either passing in api_key or setting SCOUT_API_KEY")
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.workflows = AsyncWorkflowsClient(client_wrapper=self._client_wrapper)
        self.environments = AsyncEnvironmentsClient(client_wrapper=self._client_wrapper)
        self.revisions = AsyncRevisionsClient(client_wrapper=self._client_wrapper)
        self.usage = AsyncUsageClient(client_wrapper=self._client_wrapper)
        self.workflow_logs = AsyncWorkflowLogsClient(client_wrapper=self._client_wrapper)
        self.copilots = AsyncCopilotsClient(client_wrapper=self._client_wrapper)
        self.collections = AsyncCollectionsClient(client_wrapper=self._client_wrapper)
        self.tables = AsyncTablesClient(client_wrapper=self._client_wrapper)
        self.documents = AsyncDocumentsClient(client_wrapper=self._client_wrapper)
        self.sources = AsyncSourcesClient(client_wrapper=self._client_wrapper)
        self.syncs = AsyncSyncsClient(client_wrapper=self._client_wrapper)


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: ScoutEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class SourceArchetype(UncheckedBaseModel):
    archetype_id: str = pydantic.Field()
    """
    The unique identifier for this source archetype
    """

    display_name: str = pydantic.Field()
    """
    The human readable name for this source archetype
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    A description of this source archetype
    """

    schedulable: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Wether or not this Source can be schedule to run at an interval
    """

    img_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    A URL to an image representing this source archetype
    """

    input_schema: typing.Dict[str, typing.Optional[typing.Any]] = pydantic.Field()
    """
    The input schema for this source archetype
    """

    integrated_service_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Determines if the SourceSync is a IntegratedService
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
